@@ -6,7 +6,7 @@ use Compiler::Lexer;
 use CPAN::Meta::Requirements;
 use Perl::PrereqScanner::Lite::Constants;
 
-our $VERSION = "0.16";
+our $VERSION = "0.17";
 
 sub new {
     my ($class, $opt) = @_;
@@ -156,7 +156,7 @@ sub _scan {
             }
 
             # End of declare of use statement
-            if ($token_type == SEMI_COLON || $token->{data} eq ';') {
+            if ($token_type == SEMI_COLON || $token->{data} eq ';' || $token_type == LEFT_BRACE || $token_type == LEFT_BRACKET) {
                 #                            ~~~~~~~~~~~~~~~~~~~~~ XXX This problem fixed at https://github.com/goccy/p5-Compiler-Lexer/commit/248c63b6ebf8234657f775e8bd76760af3d00134
                 #                                                  But it has not released yet (in 2014-03-23).
                 if ($module_name && !$does_use_lib_or_constant) {
@@ -383,6 +383,20 @@ For example
 
 In this case C<Foo> is the prereq, however C<Bar> is ignored.
 
+=head1 SPEED COMPARISON
+
+=head2 Plain
+
+                                Rate   Perl::PrereqScanner Perl::PrereqScanner::Lite
+    Perl::PrereqScanner       8.57/s                    --                      -97%
+    Perl::PrereqScanner::Lite  246/s                 2770%                        --
+
+=head2 With Moose scanner
+
+                                Rate   Perl::PrereqScanner Perl::PrereqScanner::Lite
+    Perl::PrereqScanner       9.00/s                    --                      -94%
+    Perl::PrereqScanner::Lite  152/s                 1587%                        --
+
 =head1 SEE ALSO
 
 L<Perl::PrereqScanner>, L<Compiler::Lexer>
